package com.icomsys.main_vm.db.mybatis.mapper;

import com.icomsys.main_vm.db.mybatis.alias.MonitoringIntentAnalysisVO;
import org.apache.ibatis.annotations.Mapper;

import java.util.HashMap;
import java.util.List;

@Mapper
public interface IntentAnalysisMapper {
    List<HashMap> selectIntentNameList(MonitoringIntentAnalysisVO vo);
    String selectServiceGroupUpper(MonitoringIntentAnalysisVO vo);
    String selectOprByServiceCode(MonitoringIntentAnalysisVO vo);
    List<HashMap> selectIntentAnalysisList(MonitoringIntentAnalysisVO vo);
    int selectIntentAnalysisListCnt(MonitoringIntentAnalysisVO vo);
}
